==> viso-sdk-python-1.0.1.tar.gz: viso-sdk-python-1.0.1/CHANGELOG.md <==
# Changelog

<!--next-version-placeholder-->

## v0.1.3

### Enhancements
- Update visualization for dynamic fonts  

### Features

### Fix
- init_font() - the case of not existing font_name


## v0.2.2

### Enhancements
### Features
- new declaration of modules 
### Fix
- VizObj, VizRoi - missed arguments (text_color)
- update default shadow_color with pillow RGBA format(255, 0, 0, 255) = RED
 
## v0.2.3

### Enhancements
### Features
- added drawer function for (line-type) roi objects  
### Fix
- visualize.utils.put_text() - correct padding calculation
- visualize.utils.put_text() - treat multi-line text too
- visualize.utils.put_text() - added option for center align


## v0.2.4

### Enhancements
### Features
- sphinx autodoc  
### Fix


## v0.2.5

### Enhancements
### Features
### Fix
- update function to calculate padding in the case of multi-line text
- add new framework TensorRT
- update utils.put_text() parameter names


## v0.2.6

### Enhancements
### Features
### Fix
- update other viz functions (vis_obj, vis_roi) using updated utils.put_text()


## v0.2.7(v0.2.8)
### Enhancements
- constants - add common keys for object tracking/recognition
- visualization:
  - add draw_tracking_objects
  - ignore empty object lists on visualization function 
### Features


## v0.2.9
### Enhancements
- more detailed visualization parameters 
### Features


## v0.2.10
### Enhancements
- update to python3.10 
### Features

## v0.2.11
### Enhancements
- remove pillow version 
### Features

## v0.2.12/v0.2.13
### Enhancements
- add member functions into __init__.py (redis and mqtt)
### Features

### Fix
- remove func redis_wrapper.gen_redis_key_status()

## v0.2.14
### Enhancements
- add instance object for detection result
### Features
### Fix
- indicate proper paho-mqtt version


## v0.2.15
### Enhancements
### Features
- soft merge redis_meta with redis_encoding
### Fix


## v1.0.0 = v0.2.15

## v1.0.1
### Enhancements
- viso_data(), default version is set 1 
### Features
- integrate viso_data into redis_utils 
### Fix
- status_logger using new redis_utils
- redis_wrapper decoding bytes to str

==> viso-sdk-python-1.0.4.tar.gz: viso-sdk-python-1.0.4/CHANGELOG.md <==
# Changelog

<!--next-version-placeholder-->

## v0.1.3

### Enhancements
- Update visualization for dynamic fonts  

### Features

### Fix
- init_font() - the case of not existing font_name


## v0.2.2

### Enhancements
### Features
- new declaration of modules 
### Fix
- VizObj, VizRoi - missed arguments (text_color)
- update default shadow_color with pillow RGBA format(255, 0, 0, 255) = RED
 
## v0.2.3

### Enhancements
### Features
- added drawer function for (line-type) roi objects  
### Fix
- visualize.utils.put_text() - correct padding calculation
- visualize.utils.put_text() - treat multi-line text too
- visualize.utils.put_text() - added option for center align


## v0.2.4

### Enhancements
### Features
- sphinx autodoc  
### Fix


## v0.2.5

### Enhancements
### Features
### Fix
- update function to calculate padding in the case of multi-line text
- add new framework TensorRT
- update utils.put_text() parameter names


## v0.2.6

### Enhancements
### Features
### Fix
- update other viz functions (vis_obj, vis_roi) using updated utils.put_text()


## v0.2.7(v0.2.8)
### Enhancements
- constants - add common keys for object tracking/recognition
- visualization:
  - add draw_tracking_objects
  - ignore empty object lists on visualization function 
### Features


## v0.2.9
### Enhancements
- more detailed visualization parameters 
### Features


## v0.2.10
### Enhancements
- update to python3.10 
### Features

## v0.2.11
### Enhancements
- remove pillow version 
### Features

## v0.2.12/v0.2.13
### Enhancements
- add member functions into __init__.py (redis and mqtt)
### Features

### Fix
- remove func redis_wrapper.gen_redis_key_status()

## v0.2.14
### Enhancements
- add instance object for detection result
### Features
### Fix
- indicate proper paho-mqtt version


## v0.2.15
### Enhancements
### Features
- soft merge redis_meta with redis_encoding
### Fix


## v1.0.0 = v0.2.15

## v1.0.1
### Enhancements
- viso_data(), default version is set 1 
### Features
- integrate viso_data into redis_utils 
### Fix
- status_logger using new redis_utils
- redis_wrapper decoding bytes to str

## v1.0.2
### Enhancements
- viso_data() - split into sub dataclasses MetaSource(), MetaModule(), MetaFrameFormat()

## v1.0.4
### Fix
- viso_data.meta.source.update() - Fix attribute error when new attribute comes
